# wofry
Wave Optics FRamwork in pYthon

WOFRY [1] is the OASYS framework for waveoptics calculations. It contains a threefold functionality: 
- it provides a generalization (or abstraction) of a software tool for wave optics, combining the component definitions from SYNED with the abstract declaration of wavefronts and propagators
- it defines a mechanism for interfacing a wave optics code (e.g., SRW, WISE etc.) in it, a first step for becoming interfaced in OASYS
- it provides native implementations of simple wavefronts (e.g., plane waves, spherical waves, Gaussian sources) and propagators [2] for prototyping optical systems.

## References

[1] https://doi.org/10.1117/12.2274232

[2] https://github.com/oasys-kit/documents/blob/master/zoom_propagator_pirro_thesis.pdf
